/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.chart;

import de.intevation.gnv.geobackend.base.Result;

import java.util.Collection;
import java.util.Locale;

import org.apache.log4j.Logger;

import org.jfree.chart.ChartTheme;

import org.jfree.data.general.Series;

/**
 * Implementation to create a special type of horizontal profile charts.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class HorizontalCrossProfileChart
extends      HorizontalProfileChart
{
    /**
     * Logger used for logging with log4j.
     */
    private static Logger log = Logger.getLogger(HorizontalCrossProfileChart.class);

    /**
     * Constructor to create HorizontalCrossProfileChart objects.
     *
     * @param labels Labels used to be displayed in title, subtitle and so on.
     * @param theme ChartTheme used to adjust the rendering of this chart.
     * @param parameters Collection containing a bunch of parameters.
     * @param measurements Collection containing a bunch of measurements.
     * @param dates Collection containing a bunch of date objects.
     * @param result Collection containing a bunch of <code>Result</code>
     * objects which contain the actual data items to be displayed.
     * @param timeGaps Collection with timegap definitions.
     * @param locale Locale used to specify the format of labels, numbers, ...
     * @param linesVisible Render lines between data points if true, otherwise
     * not.
     * @param shapesVisible Render vertices as points if true, otherwise not.
     */
    public HorizontalCrossProfileChart(
        ChartLabels labels,
        ChartTheme  theme,
        Collection  parameters,
        Collection  measurements,
        Collection  dates,
        Collection  result,
        Collection  timeGaps,
        Locale      locale,
        boolean     linesVisible,
        boolean     shapesVisible
    ) {
        super(
            labels,
            theme,
            parameters,
            measurements,
            dates,
            result,
            timeGaps,
            locale,
            linesVisible,
            shapesVisible
        );
    }


    /**
     * Method for gap detection. Nothing is done here, because in this type of
     * chart no gap detection takes place.
     *
     * @see de.intevation.gnv.chart.HorizontalProfileChart#gapDetection(Result[],
     * Series, int, int)
     */
    @Override
    protected void gapDetection(
        Result[] results,
        Series   series,
        int      startPos,
        int      endPos
    ) {
        // nothing to do here, gap detection is done in interpolation
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
